Module audit

Module audit 

Audit trail logging and queries.

Structs

AuditEntry
A recorded audit event.
AuditEvent
Canonical event envelope for audit writes and mirrored disk logs.
AuditService
Service for recording and querying audit events.

Enums

AuditAction
Actions that can be recorded in the audit log.
AuditActorSource
Source subsystem that emitted an audit event.
AuditExportFormat
Output formats supported when exporting audit logs.